/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.key;

import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.domain.key.KeyAlarmRule;
import com.yiring.auth.domain.user.User;
import java.io.Serial;
import java.io.Serializable;
import java.util.Set;
import lombok.*;
import lombok.experimental.FieldDefaults;

/**
 * 按键报警规则导出
 *
 * @author LJ-2204
 * @date 2022/5/7
 */
@ExcelModel
@Data
@Builder
@FieldDefaults(level = AccessLevel.PRIVATE)
public class KeyAlarmRuleExportExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = -800228727313291675L;

    @ExcelColumn(title = "部门名称")
    String deptName;

    @ExcelColumn(title = "负责人")
    String userNames;

    @ExcelColumn(title = "通知类型")
    String types;

    public static KeyAlarmRuleExportExcel transform(KeyAlarmRule keyAlarmRule) {
        Set<User> users = keyAlarmRule.getUsers();
        StringBuilder userNames = new StringBuilder();
        for (User user : users) {
            userNames.append(user.getRealName());
            userNames.append("、");
        }
        String substring = userNames.substring(0, userNames.length() - 1);

        return KeyAlarmRuleExportExcel
            .builder()
            .deptName(keyAlarmRule.getDepartment().getName())
            .userNames(substring)
            .types(keyAlarmRule.getTypes())
            .build();
    }
}
