/* (C) 2022 YiRing, Inc. */
package com.yiring.app.excel.rehearsal;

import com.github.liaochong.myexcel.core.annotation.ExcelColumn;
import com.github.liaochong.myexcel.core.annotation.ExcelModel;
import com.yiring.app.constant.rehearsal.RehearsalPlanStatusEnum;
import com.yiring.app.constant.rehearsal.RiskLevelEnum;
import com.yiring.app.domain.rehearsal.RehearsalPlan;
import java.io.Serial;
import java.io.Serializable;
import java.time.LocalDateTime;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

/**
 * @author tml
 * @version 1.0
 * @date 2022/5/10 13:48
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
@Builder
@ExcelModel
public class RehearsalPlanExcel implements Serializable {

    @Serial
    private static final long serialVersionUID = -2976618459214077036L;

    @ExcelColumn(title = "演练主题")
    private String topical;

    @ExcelColumn(title = "事故点")
    private String accidentSpotName;

    @ExcelColumn(title = "周边范围(m)")
    private Integer scope;

    @ExcelColumn(title = "撤离点")
    private String evacuationZoneName;

    @ExcelColumn(title = "风险程度")
    private String riskLevelName;

    @ExcelColumn(title = "事故信息")
    private String accidentMsg;

    @ExcelColumn(title = "演练时间")
    private LocalDateTime rehearsalTime;

    @ExcelColumn(title = "推送信息")
    private String pushMsg;

    @ExcelColumn(title = "状态")
    private String statusName;

    public static RehearsalPlanExcel transform(RehearsalPlan rehearsalPlan) {
        return RehearsalPlanExcel
            .builder()
            .topical(rehearsalPlan.getTopical())
            .accidentSpotName(rehearsalPlan.getAccidentSpot().getName())
            .scope(rehearsalPlan.getScope())
            .evacuationZoneName(rehearsalPlan.getEvacuationZone().getName())
            .riskLevelName(RiskLevelEnum.getByCode(rehearsalPlan.getRiskLevel()))
            .accidentMsg(rehearsalPlan.getAccidentMsg())
            .rehearsalTime(rehearsalPlan.getRehearsalTime())
            .pushMsg(rehearsalPlan.getPushMsg())
            .statusName(RehearsalPlanStatusEnum.getByCode(rehearsalPlan.getStatus()))
            .build();
    }
}
