/* (C) 2022 YiRing, Inc. */
package com.yiring.app.service.location.tag;

import com.yiring.app.param.location.tag.*;
import com.yiring.app.vo.location.tag.LocationTagIndexVo;
import com.yiring.app.vo.location.tag.LocationTagVo;
import com.yiring.common.core.Result;
import com.yiring.common.param.IndexParam;
import com.yiring.common.param.PageParam;
import com.yiring.common.vo.PageVo;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.multipart.MultipartFile;

/**
 * 定位标签
 * @author LJ-2204
 * @date 2022/4/14
 */
public interface LocationTagService {
    /**
     * 新增定位标签
     * @param locationTagAddParam LocationTagAddParam
     * @return Result<String>
     */
    Result<String> addLocationTag(LocationTagAddParam locationTagAddParam);

    /**
     * 分页查询
     * @param param LocationTagFindParam
     * @return Result<PageVo<LocationTagVo>>
     */
    Result<PageVo<LocationTagVo>> findLocationTagPage(LocationTagFindParam param, PageParam pageParam);

    /**
     * 销毁定位标签
     * @param locationTagDeleteParam 入参
     * @return Result<String>
     */
    Result<String> deleteLocationTag(LocationTagDeleteParam locationTagDeleteParam);

    /**
     * 导出定位标签
     * @param param 入参
     * @param response 响应信息
     */
    void exportLocationTagInfo(LocationTagFindParam param, HttpServletResponse response);

    /**
     * 导入定位标签
     * @param file 文件
     * @return Result<String>
     */
    Result<String> importLocationTagInfo(MultipartFile file);

    /**
     * 检索标签
     * @param indexParam IndexParam
     * @return Result<PageVo<LocationTagIndexVo>>
     */
    Result<PageVo<LocationTagIndexVo>> indexLocationTag(IndexParam indexParam);

    /**
     * 条件查询
     * @param param LocationTagFindParam
     * @return Result<PageVo<LocationTagVo>>
     */
    Result<PageVo<LocationTagVo>> findLocationTag(LocationTagFindParam param);

    /**
     * 标签详细信息
     * @param param LocationTagFindParam
     * @return Result<LocationTagVo>
     */
    Result<LocationTagVo> info(LocationTagFindParam param);
}
